require_relative './spec_helper'

describe "init" do

  before do
    VCR.insert_cassette 'base', :record => :new_episodes
  end
  after do
    VCR.eject_cassette
  end

  describe "default instance attributes" do
    let(:package) { Pactrack::Package.new('69118566702SE') }
    it "must have an id attribute" do
      package.must_respond_to :id
    end
    it "must have the right id" do
      package.id.must_equal '69118566702SE'
    end
  end
  
  describe "dynamic attributes" do
    let(:package) { Pactrack::Package.new('69118566702SE') }
    it "must return the attribute value if present in profile" do
      package.customerno.must_equal '4155047006'
    end
    it "must raise method missing if attribute is not present" do
      lambda { package.foo_attribute }.must_raise NoMethodError
    end
  end
  
  describe "caching" do
    let(:package) { Pactrack::Package.new('69118566702SE') }
    before do
      package.parcel
      stub_request(:any, "http://server.logistik.posten.se/servlet/PacTrack?lang=SE&kolliid=69118566702SE").to_timeout
    end
    it "must cache the profile" do
      package.parcel.must_be_instance_of Hash
    end
    it "must refresh the profile if forced" do
      lambda { package.parcel(true) }.must_raise Timeout::Error
    end
  end
  
  describe "nice attributes" do
    let(:package) { Pactrack::Package.new('69118566702SE') }
    it "must return events attribute that equals event attribute" do
      package.events.must_equal package.event
    end
    it "must return weight attribute that equals actualweight attribute" do
      package.weight.must_equal package.actualweight
    end
    it "must return status attribute that equals statusdescription attribute" do
      package.status.must_equal package.statusdescription
    end
  end  
  
  describe "Get Package" do
    let(:package) { Pactrack::Package.new('69118566702SE') }
    it "must have a parcel method" do
      package.must_respond_to :parcel
    end
    it "must parse the api response from XML to Hash" do
      package.parcel.must_be_instance_of Hash
    end
    it "must get the right parcel" do
      package.parcel['id'].must_equal '69118566702SE'
    end
  end
  
  describe Pactrack::Package do
    it "must have the base url set to the Package API endpoint" do
        Pactrack::Package.base_uri.must_equal 'http://server.logistik.posten.se/servlet/PacTrack'
    end
    it "must include httparty methods" do
        Pactrack::Package.must_include HTTParty
    end
  end
  
end
